@@ -58,7 +58,7 @@ class quantum_lab():
         data = response.json()
         
         print("{:<6} {:<15}".format("ID", "Created Status"))
-        print("{:<6} {:<15}".format(data["jobId"], 'Success' if data["status"] else 'Fail'))
+        print("{:<6} {:<15}".format(data["id"], 'Success' if data["status"] else 'Fail'))
 
         jobID = data["id"]
 
@@ -151,7 +151,7 @@ class quantum_lab():
                 ele["resourceId"], 
                 ele["resourceName"], 
                 'True' if ele["jobRegStatus"] else 'False', 
-                ele["jobStatus"], 
+                'NotReady' if ele["jobStatus"] is None else ele["jobStatus"],
                 ele["jobShot"],
                 ele["jobUploadType"],
                 ele["jobFilePath"].split('/')[-1],
